/*
******************************************************************************

   OVL implementation for X target - API functions.

   Copyright (C) 2001	Christoph Egger	[Christoph_Egger@t-online.de]

   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/

#include <stdio.h>

#include "xovl.h"


#include <ggi/display/xcommon.h>
#include <ggi/display/x.h>

#include <X11/X.h>



/* Transfer the contents in buf from/to the sprite.
 * The direct access is emulated by using a system RAM buffer.
 */


int setmem(ggiOvl_t ovl, void *buf)
{
	int rc = GALLOC_OK;

	if (ggiOvlDirectAccess(ovl)) {
		return GALLOC_EUNAVAILABLE;
	}	/* if */


	rc = ggiPutBox(
		ovl->common.write,
		ovl->x, ovl->y, ovl->w, ovl->h, buf);

	return rc;
}	/* setmem */



int getmem(ggiOvl_t ovl, void *buf)
{
	int rc = GALLOC_OK;

	if (ggiOvlDirectAccess(ovl)) {
		return GALLOC_EUNAVAILABLE;
	}	/* if */

	rc = ggiGetBox(
		ovl->common.read,
		ovl->x,ovl->y, ovl->w,ovl->h, buf);

	return rc;
}	/* getmem */




/* Transfer the contents in buf from/to the sprite.
 * The direct access to the VRAM is available.
 */

int setdb(ggiOvl_t ovl, void *buf)
{
	int rc = GALLOC_OK;

	if (!ggiOvlDirectAccess(ovl)) {
		return GALLOC_EUNAVAILABLE;
	}	/* if */


	rc = ggiPutBox(
		ovl->common.write,
		ovl->x, ovl->y, ovl->w, ovl->h, buf);

	return rc;
}	/* setdb */



int getdb(ggiOvl_t ovl, void *buf)
{
	int rc = GALLOC_OK;

	if (!ggiOvlDirectAccess(ovl)) {
		return GALLOC_EUNAVAILABLE;
	}	/* if */


	rc = ggiGetBox(
		ovl->common.read,
		ovl->x,ovl->y, ovl->w,ovl->h, buf);

	return rc;
}	/* getdb */

